@@ -6,9 +6,10 @@ from .ConfigEnum import ConfigEnum
 class Brain:
 
     def __init__(self, mode=0):
+        self.config = ConfigEnum()
         self.modeSwitcher = {
-            0: ConfigEnum.get("CNN_DEFAULT_MODEL"),
-            1: ConfigEnum.get("CNN_30MIN_MODEL")
+            0: self.config.get("CNN_DEFAULT_MODEL"),
+            1: self.config.get("CNN_30MIN_MODEL")
         }
         self.model = None
         self.init(self.modeSwitcher[mode])
