@@ -1,5 +1,5 @@
 from pkg_resources import resource_filename, Requirement
-class ConfigEnum(Enum):
+class ConfigEnum():
     def __init__(self):
         self.dict = {
             "IMAGE_HEIGHT": 128,
