@@ -7,6 +7,7 @@ from .ConfigEnum import ConfigEnum
 
 class Image:
     def __init__(self, image=None, path=""):
+        self.config = ConfigEnum()
         if image: 
             self.image = image
         if path:
@@ -30,7 +31,7 @@ class Image:
 
     def resize(self,image):
         image = np.uint8(image)
-        image = PilImage.fromarray(image).resize((ConfigEnum.get("IMAGE_WIDTH"), ConfigEnum.get("IMAGE_HEIGHT")))
+        image = PilImage.fromarray(image).resize((self.config.get("IMAGE_WIDTH"), self.config.get("IMAGE_HEIGHT")))
         return np.array(image)
 
     def normalize(self, image):
